# Generated by Django 5.2.6 on 2025-10-03 01:36

import django.core.validators
import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ('django_ledger', '0026_stagedtransactionmodel_customer_model_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='accountmodel',
            name='role',
            field=models.CharField(
                choices=[
                    (
                        'Assets',
                        [
                            ('asset_ca_cash', 'Current Asset'),
                            ('asset_ca_mkt_sec', 'Marketable Securities'),
                            ('asset_ca_recv', 'Receivables'),
                            ('asset_ca_inv', 'Inventory'),
                            ('asset_ca_uncoll', 'Uncollectibles'),
                            ('asset_ca_prepaid', 'Prepaid'),
                            ('asset_ca_other', 'Other Liquid Assets'),
                            ('asset_lti_notes', 'Notes Receivable'),
                            ('asset_lti_land', 'Land'),
                            ('asset_lti_sec', 'Securities'),
                            ('asset_ppe_build', 'Buildings'),
                            ('asset_ppe_build_accum_depr', 'Buildings - Accum. Depreciation'),
                            ('asset_ppe_plant', 'Plant'),
                            ('asset_ppe_plant_depr', 'Plant - Accum. Depreciation'),
                            ('asset_ppe_equip', 'Equipment'),
                            ('asset_ppe_equip_accum_depr', 'Equipment - Accum. Depreciation'),
                            ('asset_ia', 'Intangible Assets'),
                            ('asset_ia_accum_amort', 'Intangible Assets - Accum. Amortization'),
                            ('asset_adjustment', 'Other Assets'),
                        ],
                    ),
                    (
                        'Liabilities',
                        [
                            ('lia_cl_acc_payable', 'Accounts Payable'),
                            ('lia_cl_credit_line', 'Credit Line'),
                            ('lia_cl_wages_payable', 'Wages Payable'),
                            ('lia_cl_int_payable', 'Interest Payable'),
                            ('lia_cl_taxes_payable', 'Taxes Payable'),
                            ('lia_cl_st_notes_payable', 'Short Term Notes Payable'),
                            ('lia_cl_ltd_mat', 'Current Maturities of Long Tern Debt'),
                            ('lia_cl_def_rev', 'Deferred Revenue'),
                            ('lia_cl_other', 'Other Liabilities'),
                            ('lia_ltl_notes', 'Long Term Notes Payable'),
                            ('lia_ltl_bonds', 'Bonds Payable'),
                            ('lia_ltl_mortgage', 'Mortgage Payable'),
                        ],
                    ),
                    (
                        'Equity',
                        [
                            ('eq_capital', 'Capital'),
                            ('eq_stock_common', 'Common Stock'),
                            ('eq_stock_preferred', 'Preferred Stock'),
                            ('eq_adjustment', 'Other Equity Adjustments'),
                            ('eq_dividends', 'Dividends & Distributions to Shareholders'),
                            ('in_operational', 'Operational Income'),
                            ('in_passive', 'Investing/Passive Income'),
                            ('in_interest', 'Interest Income'),
                            ('in_gain_loss', 'Capital Gain/Loss Income'),
                            ('in_other', 'Other Income'),
                            ('cogs_regular', 'Cost of Goods Sold'),
                            ('ex_regular', 'Regular Expense'),
                            ('ex_interest_st', 'Interest Expense - Short Term Debt'),
                            ('ex_interest', 'Interest Expense - Long Term Debt'),
                            ('ex_taxes', 'Tax Expense'),
                            ('ex_capital', 'Capital Expense'),
                            ('ex_depreciation', 'Depreciation Expense'),
                            ('ex_amortization', 'Amortization Expense'),
                            ('ex_other', 'Other Expense'),
                        ],
                    ),
                    (
                        'Root',
                        [
                            ('root_coa', 'CoA Root Account'),
                            ('root_assets', 'Assets Root Account'),
                            ('root_liabilities', 'Liabilities Root Account'),
                            ('root_capital', 'Capital Root Account'),
                            ('root_income', 'Income Root Account'),
                            ('root_cogs', 'COGS Root Account'),
                            ('root_expenses', 'Expenses Root Account'),
                        ],
                    ),
                ],
                max_length=30,
                verbose_name='Account Role',
            ),
        ),
        migrations.AlterField(
            model_name='receiptmodel',
            name='amount',
            field=models.DecimalField(
                decimal_places=2,
                help_text='Amount of the receipt.',
                max_digits=20,
                validators=[django.core.validators.MinValueValidator(limit_value=0)],
                verbose_name='Receipt Amount',
            ),
        ),
        migrations.AlterField(
            model_name='receiptmodel',
            name='receipt_account',
            field=models.ForeignKey(
                blank=True,
                help_text='The income or expense account where this transaction will be reflected',
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to='django_ledger.accountmodel',
                verbose_name='PnL Account',
            ),
        ),
        migrations.AlterField(
            model_name='receiptmodel',
            name='receipt_type',
            field=models.CharField(
                choices=[
                    ('sales', 'Sales Receipt'),
                    ('customer_refund', 'Sales Refund'),
                    ('expense', 'Expense Receipt'),
                    ('expense_refund', 'Expense Refund'),
                    ('transfer', 'Transfer Receipt'),
                    ('debt_paydown', 'Debt Paydown Receipt'),
                ],
                max_length=15,
                verbose_name='Receipt Type',
            ),
        ),
        migrations.AlterField(
            model_name='stagedtransactionmodel',
            name='receipt_type',
            field=models.CharField(
                blank=True,
                choices=[
                    ('sales', 'Sales Receipt'),
                    ('customer_refund', 'Sales Refund'),
                    ('expense', 'Expense Receipt'),
                    ('expense_refund', 'Expense Refund'),
                    ('transfer', 'Transfer Receipt'),
                    ('debt_paydown', 'Debt Paydown Receipt'),
                ],
                help_text='The receipt type of the transaction.',
                max_length=20,
                null=True,
                verbose_name='Receipt Type',
            ),
        ),
    ]
