{% extends 'django_ledger/layouts/content_layout_1.html' %}
{% load i18n %}
{% load static %}
{% load django_ledger %}

{% block header_buttons %}
    <a href="{{ account.get_absolute_url }}"
       class="button is-dark  is-outlined">
        <span class="icon">{% icon 'bi:arrow-left' 16 %}</span>
        <span>{% trans 'Back to Detail' %}</span>
    </a>
{% endblock %}

{% block view_content %}
    <div class="columns is-centered">
        <div class="column is-8-tablet is-6-desktop">
            <div class="box">
                <form method="post">
                    {% csrf_token %}
                    {{ form.as_p }}
                    <hr>
                    <button type="submit" class="button is-primary is-fullwidth">
                        <span class="icon">{% icon 'bi:save' 16 %}</span>
                        <span>{% trans 'Update Account' %}</span>
                    </button>
                </form>
            </div>
        </div>
    </div>
{% endblock %}