{% extends 'django_ledger/layouts/content_layout_1.html' %}
{% load i18n %}
{% load static %}
{% load icon from django_ledger %}

{% block header_buttons %}
    <a href="{{ entity_model.get_coa_create_url }}"
       class="button is-success  is-outlined">
        <span class="icon">{% icon 'bi:plus-lg' 20 %}</span>
        <span>{% trans 'Create CoA' %}</span>
    </a>
    {% if not inactive %}
        <a class="button is-warning  is-outlined" href="{{ entity_model.get_coa_list_inactive_url }}">
            <span class="icon">{% icon 'bi:eye-slash' 16 %}</span>
            <span>{% trans 'Show Inactive' %}</span>
        </a>
    {% else %}
        <a class="button is-warning  is-outlined" href="{{ entity_model.get_coa_list_url }}">
            <span class="icon">{% icon 'bi:eye' 16 %}</span>
            <span>{% trans 'Show Active' %}</span>
        </a>
    {% endif %}
{% endblock %}

{% block view_content %}
    <div class="columns is-centered is-multiline">
        {% for coa_model in coa_list %}
            <div class="column is-6">
                {% include 'django_ledger/chart_of_accounts/includes/coa_card.html' with coa_model=coa_model %}
            </div>
        {% endfor %}
    </div>
{% endblock %}


